import 'package:built_collection/built_collection.dart';
import 'package:built_value/serializer.dart';
import 'package:rxdart/rxdart.dart';

extension ListBuilderExt<T> on ListBuilder<T> {
  void removeWhereNull() => removeWhere((value) => value == null);
}

extension SubjectBuiltMapExt<K, V> on Subject<BuiltMap<K, V>> {
  Future<void> rebuild(void updates(MapBuilder<K, V> builder)) async {
    final oldMap = await first;
    add(oldMap.rebuild(updates));
  }
}

extension SubjectBuiltListExt<V> on Subject<BuiltList<V>> {
  Future<void> rebuild(void updates(ListBuilder<V> builder)) async {
    final oldMap = await first;
    add(oldMap.rebuild(updates));
  }

//  Future<void> putIfAbsent(K key, V creator()) async {
//    final oldMap = await first;
//    if (!oldMap.containsKey(key)) add(oldMap.rebuild((builder) => builder[key] = creator()));
//  }
}

extension StreamExtSerializer<T> on Stream<T> {
  Stream<Object> serialize(Serializers serializers) => map((item) {
        return serializers.serialize(item);
      });

  Stream<BuiltList<T>> deserialize<T>(Serializers serializers) => map((item) {
        if (item is List)
          return BuiltList.of(item.map((item) => serializers.deserialize(item) as T));
        return serializers.deserialize(item);
      });

  Stream<Object> serializeWith(Serializers serializers, Serializer<T> serializer) => map((item) {
        return serializers.serializeWith(serializer, item);
      });

  Stream<BuiltList<T>> deserializeWith<T>(Serializers serializers, Serializer<T> serializer) =>
      map((item) {
        if (item is List)
          return BuiltList.of(item.map((item) {
            return serializers.deserializeWith(item, serializer);
          }));
        return serializers.deserialize(item);
      });
}
